OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календарь",
    "Tasks" : "Задачи",
    "Personal" : "Личное",
    "{actor} created calendar {calendar}" : "{actor} создал(а) календарь «{calendar}»",
    "You created calendar {calendar}" : "Вы создали календарь «{calendar}»",
    "{actor} deleted calendar {calendar}" : "{actor} удалил(а) календарь «{calendar}»",
    "You deleted calendar {calendar}" : "Вы удалили календарь «{calendar}»",
    "{actor} updated calendar {calendar}" : "{actor} обновил(а) календарь «{calendar}»",
    "You updated calendar {calendar}" : "Вы обновили календарь «{calendar}»",
    "{actor} restored calendar {calendar}" : "{actor} восстановил(а) календарь «{calendar}»",
    "You restored calendar {calendar}" : "Вы восстановили календарь «{calendar}»",
    "You shared calendar {calendar} as public link" : "Вы предоставили общий доступ к календарю «{calendar}» созданием общедоступной ссылки",
    "You removed public link for calendar {calendar}" : "Вы удалили общедоступную ссылку на календарь «{calendar}»",
    "{actor} shared calendar {calendar} with you" : "{actor} предоставил(а) вам общий доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with {user}" : "Вы предоставили пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with {user}" : "{actor} предоставил(а) пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from you" : "{actor} закрыл(а) вам доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from {user}" : "Вы закрыли пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} закрыл(а) себе доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with group {group}" : "Вы предоставили группе {group} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} предоставил(а) группе {group} общий доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from group {group}" : "Вы закрыли группе {group} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} закрыл(а) группе {group} общий доступ к календарю «{calendar}»",
    "Untitled event" : "Событие без названия",
    "{actor} created event {event} in calendar {calendar}" : "{actor} создал(а) событие «{event}» в календаре «{calendar}»",
    "You created event {event} in calendar {calendar}" : "Вы создали событие «{event}» в календаре «{calendar}»",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} удалил(а) событие «{event}» из календаря «{calendar}»",
    "You deleted event {event} from calendar {calendar}" : "Вы удалили событие «{event}» из календаря «{calendar}»",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обновил(а) событие «{event}» в календаре «{calendar}»",
    "You updated event {event} in calendar {calendar}" : "Вы обновили событие «{event}» в календаре «{calendar}»",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} переместил(а) событие «{event}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Вы переместили событие «{event}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} восстановил(а) событие {event} в календаре {calendar}",
    "You restored event {event} of calendar {calendar}" : "Вы восстановили событие {event} в календаре {calendar}",
    "Busy" : "Занято",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} создал(а) задачу «{todo}» в списке «{calendar}»",
    "You created to-do {todo} in list {calendar}" : "Вы создали задачу «{todo}» в списке «{calendar}»",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} удалил(а) задачу «{todo}» из списка «{calendar}»",
    "You deleted to-do {todo} from list {calendar}" : "Вы удалили задачу «{todo}» из списка «{calendar}»",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} обновил(а) задачу «{todo}» из списка «{calendar}»",
    "You updated to-do {todo} in list {calendar}" : "Вы обновили задачу «{todo}» из списка «{calendar}»",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} завершил(а) задачу «{todo}» из списка «{calendar}»",
    "You solved to-do {todo} in list {calendar}" : "Вы завершили задачу «{todo}» из списка «{calendar}»",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} повторно(а) открыл задачу «{todo}» из списка «{calendar}»",
    "You reopened to-do {todo} in list {calendar}" : "Вы повторно открыли задачу «{todo}» из списка «{calendar}»",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} переместил(а) задачу «{todo}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Вы переместили задачу «{todo}» из календаря «{sourceCalendar}» в календарь «{targetCalendar}»",
    "Calendar, contacts and tasks" : "Календарь, контакты и задачи",
    "A <strong>calendar</strong> was modified" : "Изменения <strong>календаря</strong> ",
    "A calendar <strong>event</strong> was modified" : "В календаре изменено <strong>событие</strong>",
    "A calendar <strong>to-do</strong> was modified" : "В календаре изменена <strong>задача</strong> ",
    "Contact birthdays" : "Дни рождения контакта",
    "Death of %s" : "Смерть %s",
    "Untitled calendar" : "Календарь без названия",
    "Calendar:" : "Календарь:",
    "Date:" : "Дата:",
    "Where:" : "Где:",
    "Description:" : "Описание:",
    "_%n year_::_%n years_" : ["%n год","%n года","%n лет","%n лет"],
    "_%n month_::_%n months_" : ["%n месяц","%n месяца","%n месяцев","%n месяцев"],
    "_%n day_::_%n days_" : ["%n день","%n дня","%n дней","%n дней"],
    "_%n hour_::_%n hours_" : ["%n час","%n часа","%n часов","%n часов"],
    "_%n minute_::_%n minutes_" : ["%n минута","%n минуты","%n минут","%n минут"],
    "%s (in %s)" : "%s (в %s)",
    "%s (%s ago)" : "%s (%s назад)",
    "Calendar: %s" : "Календарь: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Описание: %s",
    "Where: %s" : "Где: %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Cancelled: %1$s" : "Событие отменено: %1$s",
    "\"%1$s\" has been canceled" : "Событие «%1$s» отменено",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s принял(а) ваше приглашение",
    "%1$s has tentatively accepted your invitation" : "%1$s предварительно принял(а) ваше приглашение",
    "%1$s has declined your invitation" : "%1$s отклонил(а) ваше приглашение",
    "%1$s has responded to your invitation" : "%1$s ответил(а) на ваше приглашение",
    "Invitation updated: %1$s" : "Изменение приглашения: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s изменил(а) событие «%2$s»",
    "Invitation: %1$s" : "Приглашение: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s приглашает вас принять участие в событии «%2$s»",
    "Organizer:" : "Организатор:",
    "Attendees:" : "Участники:",
    "Title:" : "Название:",
    "Time:" : "Время:",
    "Location:" : "Местонахождение:",
    "Link:" : "Ссылка:",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "More options …" : "Дополнительные параметры…",
    "More options at %s" : "Дополнительные параметры на %s",
    "Contacts" : "Контакты",
    "{actor} created address book {addressbook}" : "{actor} создал(а) адресную книгу «{addressbook}»",
    "You created address book {addressbook}" : "Вы создали адресную книгу «{addressbook}»",
    "{actor} deleted address book {addressbook}" : "{actor} удалил(а) адресную книгу «{addressbook}»",
    "You deleted address book {addressbook}" : "Вы удалили адресную книгу «{addressbook}»",
    "{actor} updated address book {addressbook}" : "{actor} изменил(а) адресную книгу {addressbook}",
    "You updated address book {addressbook}" : "Вы изменили адресную книгу {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} предоставил(а) вам доступ к адресной книге {addressbook}",
    "You shared address book {addressbook} with {user}" : "Вы предоставили доступ пользователю {user} к адресной книге {addressbook}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} предоставил(а) пользователю {user} доступ к адресной книге {addressbook}",
    "{actor} unshared address book {addressbook} from you" : "{actor} закрыла(а) вам доступ к адресной книге {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Вы закрыли пользователю {user} доступ к адресной книге {addressbook} ",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к адресной книге {addressbook}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} закрыла(а) себе доступ к адресной книге {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Вы предоставили группе  {group} доступ к адресной книге {addressbook}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} предоставил(а) группе {group} доступ к адресной книге {addressbook}",
    "You unshared address book {addressbook} from group {group}" : "Вы закрыли группе {group} доступ к адресной книге {addressbook} ",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} закрыл(а) группе {group} доступ к адресной книге {addressbook}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} создал(а) запись {card} в адресной книге {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Вы создали запись {card} в адресной книге {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} удалил(а) запись {card} в адресной книге {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Вы удалил запись {card} в адресной книге {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} изменил(а) запись {card} в адресной книге {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Вы изменили запись {card} в адресной книге {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Изменение  <strong>контакта</strong> или <strong>адресной книги</strong>",
    "Accounts" : "Учётные записи",
    "System address book which holds all accounts" : "Системная адресная книга, в которой хранятся все учетные записи",
    "File is not updatable: %1$s" : "Файл не подлежит обновлению: %1$s",
    "Could not write to final file, canceled by hook" : "Не удалось записать результирующий файл, запись отменена вызовом обработчика",
    "Could not write file contents" : "Не удалось записать содержимое файла",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байта"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Ошибка при копировании в целевое расположение, скопировано: %1$s, ожидаемый размер файла: %2$s",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Ожидаемый размер файла составляет %1$s, но из клиента приложения Nextcloud было прочитано и записано в хранилище %2$s. К этому могла привести ошибка при передаче данных на стороне отправителя либо проблема в подсистеме хранения данных на стороне сервера.",
    "Could not rename part file to final file, canceled by hook" : "Не удалось переименовать временный файл в результирующий, операция отменена вызовом обработчика",
    "Could not rename part file to final file" : "Не удалось переименовать временный файл в результирующий",
    "Failed to check file size: %1$s" : "Не удалось проверить размер файла: %1$s",
    "Could not open file" : "Не удалось открыть файл",
    "Encryption not ready: %1$s" : "Подсистема шифрования не готова: %1$s",
    "Failed to open file: %1$s" : "Не удалось открыть файл: %1$s",
    "Failed to unlink: %1$s" : "Не удалось разорвать связь: %1$s",
    "Invalid chunk name" : "Недопустимое имя сегмента",
    "Could not rename part file assembled from chunks" : "Не удалось переименовать временный файл, сформированный из сегментов",
    "Failed to write file contents: %1$s" : "Не удалось записать содержимое файла: %1$s",
    "File not found: %1$s" : "Файл не найден: %1$s",
    "System is in maintenance mode." : "Сервер находится в режиме обслуживания.",
    "Upgrade needed" : "Требуется обновление",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s должен быть настроен на использование протокола HTTPS, чтобы можно было использовать CalDAV и CardDAV на iOS/macOS.",
    "Configures a CalDAV account" : "Настройка аккаунта CalDAV",
    "Configures a CardDAV account" : "Настройка аккаунта CardDAV",
    "Events" : "События",
    "Untitled task" : "Задача без названия",
    "Completed on %s" : "Завершено %s",
    "Due on %s by %s" : "До %s %s",
    "Due on %s" : "До %s",
    "DAV system address book" : "Системная адресная книга DAV",
    "No outstanding DAV system address book sync." : "Синхронизация системной адресной книги DAV выполнена.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Синхронизация системной адресной книги DAV ещё не запущена, поскольку в этом экземпляре более 1000 пользователей или произошла ошибка. Перезапустите синхронизацию вручную используя команду «occ dav:sync-system-addressbook».",
    "Migrated calendar (%1$s)" : "Перенос календаря (%1$s)",
    "Calendars including events, details and attendees" : "Календари, в том числе события, подробные сведения и участники",
    "Contacts and groups" : "Контакты и группы",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "точка подключения WebDAV",
    "First day" : "Первый день",
    "Last day (inclusive)" : "Последний день (включительно)",
    "Short absence status" : "Краткий статус отсутствия",
    "Long absence Message" : "Длинное сообщение об отсутствии",
    "Save" : "Сохранить",
    "Disable absence" : "Отключить отсутствие",
    "Absence saved" : "Состояние отсутствия сохранено",
    "Failed to save your absence settings" : "Не удалось сохранить параметры отсутствия",
    "Absence cleared" : "Состояние отсутствия удалено",
    "Failed to clear your absence settings" : "Не удалось удалить параметры отсутствия",
    "Time zone:" : "Часовой пояс:",
    "to" : "по",
    "Delete slot" : "Удалить интервал",
    "No working hours set" : "Рабочие часы не указаны",
    "Add slot" : "Добавить интервал",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sunday" : "Воскресенье",
    "Pick a start time for {dayName}" : "Выберите время начала в {dayName}",
    "Pick a end time for {dayName}" : "Выберите время окончания в {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматически изменять статус на «Не беспокоить» вне интервала доступности для отключения уведомлений.",
    "Failed to load availability" : "Не удалось получить сведения о доступности",
    "Saved availability" : "Сведения о доступности сохранены",
    "Failed to save availability" : "Не удалось сохранить сведения о доступности",
    "Availability" : "Рабочее время",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Если вы настроите свой расписание работы, другие пользователи при планировании встреч смогут видеть, когда вас нет в офисе.",
    "Absence" : "Отсутствие",
    "Configure your next absence period." : "Укажите интервал вашего следующего отсутствия.",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Отправить приглашения",
    "Automatically generate a birthday calendar" : "Создавать календарь дней рождения автоматически",
    "Birthday calendars will be generated by a background job." : "Календари дней рождения будут создаваться фоновым процессом.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "И поэтому они станут доступны не моментально, а через некоторое время.",
    "Send notifications for events" : "Отправлять уведомления о событиях",
    "Notifications are sent via background jobs, so these must occur often enough." : "Уведомления будут отправляться через фоновые задания, поэтому они должны выполняться достаточно часто.",
    "Send reminder notifications to calendar sharees as well" : "Отправлять напоминания всем пользователям, имеющим доступ к календарю",
    "Reminders are always sent to organizers and attendees." : "Организаторам и участникам уведомления отправляются во всех случаях.",
    "Enable notifications for events via push" : "Включить уведомления о событиях с помощью push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Также установите {calendarappstoreopen}приложение Calendar{linkclose}, или {calendardocopen}подключите ваш ПК и мобильное устройство для синхронизации ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Проверьте правильность настройки {emailopen}почтового сервера{linkclose}.",
    "There was an error updating your attendance status." : "Ошибка обновления статуса участия.",
    "Please contact the organizer directly." : "Обратитесь к организатору напрямую.",
    "Are you accepting the invitation?" : "Принять приглашение?",
    "Tentative" : "Под вопросом",
    "Your attendance was updated successfully." : "Статус участия обновлён.",
    "To-dos" : "Задачи",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Если вы настроите свое рабочее время, другие пользователи будут видеть, когда вас нет в офисе, когда они планируют встречу."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
